# SC16IS750-Python-Driver
COMPREHENSIVE FUNCTIONALITY IN PROGRESS
This is a driver written in python for interfacing with the SC16IS750. I2C interfacing achieved using SMBUS, meaning this driver should work on Linux distros.

## To-Do List
- Add control for sleep modes.
- More control functions for UART. (Like line setup: parityBit, stopBit, etc)
- More control of FIFO buffer. (Turn on/off)
- Hardware flow control on GPIO pins.
- Software flow contorl using XOn/XOff registers.
